@@ -47,6 +47,13 @@ namespace TheSeer\Autoload {
                             $this->addDirectory($baseDir);
                             continue;
                         }
+                        if (is_array($dir)) {
+                            foreach($dir as $d) {
+                                $this->addDirectory($baseDir . '/' . $d);
+                            }
+
+                            continue;
+                        }
                         $this->addDirectory($baseDir . '/' . $dir);
                     }
                 }
@@ -108,6 +115,7 @@ namespace TheSeer\Autoload {
          * @link http://php.net/manual/en/iterator.current.php
          * @return mixed Can return any type.
          */
+        #[\ReturnTypeWillChange]
         public function current() {
             return $this->directories[$this->pos];
         }
@@ -119,6 +127,7 @@ namespace TheSeer\Autoload {
          * @link http://php.net/manual/en/iterator.next.php
          * @return void Any returned value is ignored.
          */
+        #[\ReturnTypeWillChange]
         public function next() {
             $this->pos++;
         }
@@ -130,6 +139,7 @@ namespace TheSeer\Autoload {
          * @link http://php.net/manual/en/iterator.key.php
          * @return mixed scalar on success, or null on failure.
          */
+        #[\ReturnTypeWillChange]
         public function key() {
             return $this->pos;
         }
@@ -142,6 +152,7 @@ namespace TheSeer\Autoload {
          * @return boolean The return value will be casted to boolean and then evaluated.
          *       Returns true on success or false on failure.
          */
+        #[\ReturnTypeWillChange]
         public function valid() {
             return $this->pos < count($this->directories);
         }
@@ -153,6 +164,7 @@ namespace TheSeer\Autoload {
          * @link http://php.net/manual/en/iterator.rewind.php
          * @return void Any returned value is ignored.
          */
+        #[\ReturnTypeWillChange]
         public function rewind() {
             $this->pos = 0;
         }
